@@ -4,13 +4,12 @@ Toxopy (https://github.com/bchaselab/Toxopy)
 Licensed under the terms of the MIT license
 """
 
+import os
 from scipy.stats import mannwhitneyu
 import pandas as pd
-from toxopy import trials, nadlc, roi_behaviors
+from toxopy import trials, nadlc, roi_behaviors, fwarnings
 from itertools import combinations
 
-excluded_cats, trls, vois = nadlc(), trials(), roi_behaviors()
-
 
 def alphaTest(p):
     alpha = 0.05
@@ -22,41 +21,63 @@ def alphaTest(p):
 
 
 def statVal(stat, p):
-    res = 'Statistics=%.3f, p=%.3f' % (stat, p)
+    res = 'Statistics=%.2f, p=%.4f' % (stat, p)
     return res
 
 
-def boris_mw(csv_file, include_ns=True, drop_non_dlc=False):
+excluded_cats, trls, vois = nadlc(), trials(), roi_behaviors()
+
+
+def boris_mw(csv_file, include_ns=True, drop_non_dlc=False, export_csv=False, path=os.getcwd()):
     """
     df is typically "bin_data_grouped_____percentage____tidy" for the time
     budget analysis, and "bin_data_all_behaviors____frequency____tidy" for
     single behavior comparisons.
     """
     df = pd.read_csv(csv_file)
+
     if drop_non_dlc is True:
         for c in excluded_cats:
             df.drop(df[df.cat == c].index, inplace=True)
 
-    behaviors = list(df.Behavior.unique())
+    behaviors = sorted(list(df.Behavior.unique()))
 
     def slct(status, trial, behavior):
         return df[(df['infection_status'] == status) & (df['trial'] == trial) &
                   (df['Behavior'] == behavior)]['value']
 
+    if export_csv is True:
+        f = open(f'{path}/results.csv', 'w')
+        print('trial,behavior,stat,p,interpretation', file=f)
+
     for t in trls:
         print(f'\n{"-" * 60}\n{t}\n')
 
         for b in behaviors:
-            neg, pos = slct('Negative', t, b), slct('Positive', t, b)
+            neg, pos = slct('Control', t, b), slct('Infected', t, b)
+
             if sum(neg) and sum(pos) != 0:
                 stat, p = mannwhitneyu(neg, pos)
                 stat_values = statVal(stat, p)
                 result = alphaTest(p)
                 res_str = f'{b} ==> {stat_values}, {result}'
+
                 if result == 'reject H0':
                     print(f'{res_str}  *')
+                    ast = '*'
                 elif result != 'reject H0' and include_ns is True:
                     print(res_str)
+                    ast = ''
+
+                if export_csv is True:
+                    if t in trls[1::2] and b == 'Affiliative':
+                        pass
+                    else:
+                        print(f'{t},{b},{"%.2f" % stat},{"%.4f" % p}' +
+                              f'{ast},{result}', file=f)
+
+    if export_csv is True:
+        f.close()
 
 
 def roi_mw(csv_file):
@@ -75,7 +96,7 @@ def roi_mw(csv_file):
     for j in ['walls', 'middle']:
         print(f'\n{j}')
         for i in trls:
-            pos, neg = slct(i, 'Positive', j), slct(i, 'Negative', j)
+            pos, neg = slct(i, 'Infected', j), slct(i, 'Control', j)
             print(f'\n{i}')
             for voi in vois:
                 stat, p = mannwhitneyu(neg[voi], pos[voi])
@@ -129,7 +150,7 @@ def roi_diff_Btrials_Wgroup_mw(csv_file,
         f = open('results.csv', 'w')
         print('status,comparison,stat,p,interpretation', file=f)
 
-    for k in ['Negative', 'Positive']:
+    for k in ['Control', 'Infected']:
         if export_csv is not True:
             print(f'{"-" * 65}\n<< {k} >>')
         for b in vois:
@@ -149,3 +170,45 @@ def roi_diff_Btrials_Wgroup_mw(csv_file,
 
     if export_csv is True:
         f.close()
+
+
+def calc_dlc_mw(csv_file, export=False):
+
+    df = pd.read_csv(csv_file)
+
+    variables = ['vel', 'distance', 'cat_distance', 'acceleration', 'moving']
+
+    for t in trls:
+        with open(t, 'w') as f:
+            if export is False:
+                print('\nTrial:', t, '\n')
+                os.remove(t)
+            else:
+                print('trial, var, statistics, p', file=f)
+
+            for j in variables:
+
+                def slct(status):
+                    return df[(df['infection_status'] == status) & (df['trial'] == t) &
+                              (df['var'] == j)]['value']
+
+                pv, nv = slct('Infected'), slct('Control')
+                stat, p = mannwhitneyu(pv, nv)
+                alpha = 0.05
+
+                if stat != 0:
+                    if export is False:
+                        print(f'{j} ==>', statVal(stat, p), alphaTest(p))
+                    else:
+                        if p > alpha:
+                            print(f'{t},{j},{stat},{p}', file=f)
+                        elif p < alpha:
+                            print(f'{t},{j},{stat},{p},*', file=f)
+
+    if export is True:
+        combined_csv = pd.concat([pd.read_csv(f) for f in trls])
+        combined_csv.to_csv("mannwhitneyu_stats_results.csv",
+                            index=False,
+                            encoding='utf-8-sig')
+
+        [os.remove(f) for f in trls]
