@@ -12,7 +12,9 @@ from .analyze_turnpoints import analyze_turnpoints
 from .return_sem import return_sem
 from .sniff_boxplot import sniff_boxplot
 from .MannWhitney_U import *
-from .data_utils import json2tidycsv, obtain_grand_m, jsonify_dlc_avgs
+from .data_utils import *
 from .AnovaRM_diff import AnovaRM_diff
+from .PlotTurnPoints import PlotTurnPoints
+from .PlotPCA import PlotPCA
 
 from .version import __version__, VERSION
