@@ -10,9 +10,9 @@ import glob
 from pathlib import Path
 
 
-def csv2h5(path, head=[1]):
+def csv2h5(path, head=1):
     def toh5(file):
-        df = pd.read_csv(file, header=head, index_col=[0])
+        df = pd.read_csv(file, header=[head], index_col=[0])
         return df.to_hdf(f'{Path(file).stem}.h5',
                          'data',
                          mode='w',
